@@ -13,7 +13,7 @@ struct dynamicTasking
   tbb::atomic<std::size_t> counter;
 
 
-  void reset(std::size_t NofCPU, std::size_t NofTask)
+  void reset(std::size_t &NofCPU, std::size_t NofTask)
   {
     NofCore = NofCPU;
     if(NofCore > NofTask) NofCore = NofTask;
@@ -22,7 +22,7 @@ struct dynamicTasking
   }
 
 
-  dynamicTasking(std::size_t NofCPU, std::size_t NofTask)
+  dynamicTasking(std::size_t &NofCPU, std::size_t NofTask)
   {
     reset(NofCPU, NofTask);
   }
@@ -44,3 +44,9 @@ struct dynamicTasking
 
 
 
+
+
+
+
+
+
